@@ -1,11 +1,10 @@
 """Module provider for Zeit"""
-from __future__ import absolute_import
-
 import json
 import logging
 
 import requests
 
+from lexicon.exceptions import AuthenticationError
 from lexicon.providers.base import Provider as BaseProvider
 
 LOGGER = logging.getLogger(__name__)
@@ -43,7 +42,7 @@ class Provider(BaseProvider):
         result = self._get(f"/{self.domain}")
 
         if not result["uid"]:
-            raise Exception(f"Error, domain {self.domain} not found")
+            raise AuthenticationError(f"Error, domain {self.domain} not found")
 
         self.domain_id = result["uid"]
 
